@@ -12,7 +12,7 @@ from pathlib import Path
 
 from beets.dbcore import types
 from beets.library import Item
-from beets.util.confit import Subview
+from confuse import Subview
 
 # Get values as: plg_ns['__PLUGIN_NAME__']
 plg_ns = {}
